.. fortls documentation master file, created by
   sphinx-quickstart on Mon Jan 10 11:32:27 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

fortls -- Fortran Language Server
==================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   README.md
   options.rst
   editor_integration.rst
   fortls_changes.md
   modules.rst

..
   Include native markdown into native rst
   .. include:: README.md
      :parser: myst_parser.sphinx_

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
